@@ -89,9 +89,9 @@ class Config(object):
         fogDisabled=False, stepSize=0, opponents=[], fullscreen=True,
         raw=False, score=False, feature=False, render=False,
         replay=None, debug=False,
-            #connects=[], 
+            #connects=[],
             #state=c.GAME_INIT,
-            #agentRaces=[], bots=[], 
+            #agentRaces=[], bots=[],
     ):
         self._gotPorts  = False # ensure that ports are only returned if they were retrieved on this machine
         # flexible settings auto-determination
@@ -101,7 +101,6 @@ class Config(object):
         # application setup info
         self.expo       = expo
         self.version    = version # automatically calculate unless specified
-        # TODO version
         # match setup info
         self.ladder     = ladder
         self.players    = players
@@ -117,9 +116,11 @@ class Config(object):
         self.host       = host   # if defined, this config is for a slave
         self.slavePorts = slaves # if not defined, this is for the host
         self.ladderMsg  = ""
+        # pre-game behavior
+        self.scenario   = {}
         # in-game behavior
         self.fogDisabled= fogDisabled
-        self.stepSize   = int(stepSize)      
+        self.stepSize   = int(stepSize)
         self.opponents  = opponents # names of specific opponents
         self.fullscreen = fullscreen
         # observation data content
@@ -137,6 +138,8 @@ class Config(object):
         else:       self.inflate()  # ensure all objects are objects
         self.isCustom   = bool(self.opponents or self.fogDisabled or \
                                self.themap    or self.stepSize)
+        if self.version == None:
+            self.version = self.getVersion()
     ############################################################################
     def __str__(self):  return self.__repr__()
     def __repr__(self):
@@ -208,6 +211,11 @@ class Config(object):
         return self.installedApp.exec_path(vers)
     ############################################################################
     @property
+    def is64bit(self):
+        """whether the this machine is 64-bit capable or not"""
+        return self.installedApp.is64bit
+    ############################################################################
+    @property
     def installedApp(self):
         """identify the propery application to launch, given the configuration"""
         try:    return self._installedApp
@@ -352,13 +360,13 @@ class Config(object):
                 for i,p in enumerate(v):
                     try:    diff = p.difficulty.type
                     except: diff = p.difficulty
-                    if isinstance(p, PlayerPreGame):    newPs.append( (p.name, p.type.type, p.initCmd, diff, p.rating, p.selectedRace.type, self.numObserve, p.playerID) )
-                    else:                               newPs.append( (p.name, p.type.type, p.initCmd, diff, p.rating) )
+                    if isinstance(p, PlayerPreGame):    newPs.append( (p.name, p.type.type, p.initCmd, p.initOptions, diff, p.rating, p.selectedRace.type, self.numObserve, p.playerID, p.raceDefault) )
+                    else:                               newPs.append( (p.name, p.type.type, p.initCmd, p.initOptions, diff, p.rating) )
                 # TODO -- handle if type or observers params are not available (i.e. if a simple PlayerRecord, not a PlayerPreGame
                 ret[k] = newPs
                 continue
             elif k == "mode"   and self.mode:   v = v.type
-            #elif k == "state":              
+            #elif k == "state":
             elif k == "themap" and self.themap: v = v.name
             ret[k] = v
         return ret
@@ -460,7 +468,7 @@ class Config(object):
         return self.version
     ############################################################################
     def getIPaddresses(self):
-        """identify the IP addresses where this process client will launch the SC2 client""" 
+        """identify the IP addresses where this process client will launch the SC2 client"""
         if not self.ipAddress:
             self.ipAddress = ipAddresses.getAll() # update with IP address
         return self.ipAddress
