@@ -16,13 +16,20 @@ class UnknownPlayer(Exception): pass
 # file/folder information
 SC2_FILE_REPLAY         = "SC2Replay"
 SC2_FILE_MAP            = "SC2Map"
+FOLDER_LOBBY_HERE       = os.path.dirname(os.path.abspath(__file__))
 FOLDER_PLAYED_VIDEO     = "playedReplays"
 FOLDER_JSON             = "jsonData"
-FOLDER_ACTIVE_CONFIGS   = os.sep.join(os.path.abspath(__file__).split(os.sep)[:-1] + ["activeGames"])
+FOLDER_ACTIVE_CONFIGS   = os.path.join(FOLDER_LOBBY_HERE, "activeGames")
+FOLDER_MODS             = os.path.join(FOLDER_LOBBY_HERE, "mods")
 JSON_HEADERS            = ["label", "base-version", "version", "data-hash", "fixed-hash", "replay-hash"]
 FILE_GAME_VERSIONS      = "versions.json"
+FILE_EDITOR_MOD         = "Playground.SC2Mod"
 MIN_VERSION_AI_API      = 55958 # 3.16.1 is the first version that released the API
 FOLDER_IGNORED_MAPS     = ["Melee", "mini_games", "Test"]
+FOLDER_APP_SUPPORT      = "Support%s"         # reserved space to specify 32-bit or 64-bit items
+FILE_EDITOR_APP         = "SC2Switcher%s.exe" # reserved space to specify 32-bit or 64-bit items
+SUPPORT_32_BIT_TERMS    = ["", ""]
+SUPPORT_64_BIT_TERMS    = ["64", "_x64"]
 
 ################################################################################
 # misc
